@@ -53,7 +53,7 @@ class Options(object):
         self.verbose = click.option(
             '-v',
             '--verbose',
-            default=None,
+            default=False,
             type=click.BOOL,
             is_flag=True,
             multiple=False,
@@ -75,5 +75,14 @@ class Options(object):
             multiple=True,
             help='Remove suggested values for supported sections.')
 
+        self.autofix = click.option(
+            '-af',
+            '--autofix',
+            default=False,
+            type=click.BOOL,
+            is_flag=True,
+            multiple=False,
+            help='Fix changes in place.')
+
 
 options = Options()
