@@ -32,14 +32,22 @@ from cfy_lint import cli
 @cli.options.verbose
 @cli.options.format
 @cli.options.skip_suggestions
-def lint(blueprint_path, config, verbose, format, skip_suggestions=None):
+@cli.options.autofix
+def lint(blueprint_path,
+         config,
+         verbose,
+         format,
+         skip_suggestions=None,
+         autofix=False):
+
     yaml_config = YamlLintConfigExt(content=config, yamllint_rules=rules)
     skip_suggestions = skip_suggestions or ()
     try:
         report = create_report_for_file(
             blueprint_path,
             yaml_config,
-            skip_suggestions=skip_suggestions)
+            skip_suggestions=skip_suggestions,
+            autofix=autofix)
     except Exception as e:
         if verbose:
             raise e
@@ -72,12 +80,13 @@ def lint(blueprint_path, config, verbose, format, skip_suggestions=None):
 def create_report_for_file(file_path,
                            conf,
                            create_report_for_file=False,
-                           skip_suggestions=None):
+                           skip_suggestions=None,
+                           autofix=False):
     if not os.path.exists(file_path):
         raise RuntimeError('File path does not exist: {}.'.format(file_path))
     logger.info('Linting blueprint: {}'.format(file_path))
     with io.open(file_path, newline='') as f:
-        return run(f, conf, create_report_for_file, skip_suggestions)
+        return run(f, conf, create_report_for_file, skip_suggestions, autofix)
 
 
 def formatted_message(item, format=None):
